Change `ProfileTaskSegmentSnapshot` to `ThreadSnapshot` (#15)

diff --git a/profile/Profile.proto b/profile/Profile.proto
index 0ce1490..59f33d3 100644
--- a/profile/Profile.proto
+++ b/profile/Profile.proto
@@ -32,8 +32,8 @@
     rpc getProfileTaskCommands (ProfileTaskCommandQuery) returns (Commands) {
     }
 
-    // collect dumped segment snapshot
-    rpc collectSnapshot (stream ProfileTaskSegmentSnapshot) returns (Downstream) {
+    // collect dumped thread snapshot
+    rpc collectSnapshot (stream ThreadSnapshot) returns (Downstream) {
     }
 
     // report profiling task finished
@@ -51,8 +51,8 @@
     int64 lastCommandTime = 3;
 }
 
-// dumped segment snapshot
-message ProfileTaskSegmentSnapshot {
+// dumped thread snapshot
+message ThreadSnapshot {
     // profile task id
     string taskId = 1;
     // dumped segment id
@@ -62,11 +62,11 @@
     // snapshot dump sequence, start with zero
     int32 sequence = 4;
     // snapshot stack
-    ProfileTaskSegmentStack stack = 5;
+    ThreadStack stack = 5;
 }
 
-message ProfileTaskSegmentStack {
-    // snapshot code signature list
+message ThreadStack {
+    // stack code signature list
     repeated string codeSignatures = 1;
 }